@@ -1,7 +1,7 @@
 import uuid
 from dataclasses import dataclass
 from datetime import date, datetime
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, List, Optional, Union
 
 from dateutil.parser import parse
 
@@ -43,7 +43,7 @@ class Model:
                     continue
 
                 # Optional is ONE type combined with None
-                typehint = next(t for t in typehint.__args__ if t is not None)
+                typehint = next(t for t in typehint if t is not None)
 
             if isinstance(value, typehint):
                 continue
@@ -75,35 +75,25 @@ def factory(model: type, data: Union[JSONObject, List[JSONObject]]) -> type:
 class Task(Model):
     id: uuid.UUID
     name: str
-    assignee: None
+    assignee: Optional[str]
     created: datetime
     due: Optional[datetime]
-    follow_up: None
-    delegation_state: None
-    description: None
+    follow_up: Optional[str]
+    delegation_state: Optional[str]
+    description: Optional[str]
     execution_id: str
-    owner: None
-    parent_task_id: None
+    owner: Optional[str]
+    parent_task_id: Optional[uuid.UUID]
     priority: int
     process_definition_id: str
     process_instance_id: uuid.UUID
     task_definition_key: str
-    case_execution_id: None
-    case_instance_id: None
-    case_definition_id: None
+    case_execution_id: Optional[str]
+    case_instance_id: Optional[str]
+    case_definition_id: Optional[str]
     suspended: bool
-    form_key: None
-    tenant_id: None
-
-    def claim(self) -> None:
-        from bing.service.camunda import claim_task
-
-        claim_task(self.id)
-
-    def complete(self, variables: Dict[str, Any]) -> None:
-        from bing.service.camunda import complete_task
-
-        complete_task(self.id, variables)
+    form_key: Optional[str]
+    tenant_id: Optional[str]
 
 
 @dataclass
